<?php

namespace Ems\portalGestor\Service;

use Ems\portalGestor\Repository\EstruturaRepository;
use Ems\portalGestor\Util\{ ArrayUtil, HcmServices };

class EstruturaService
{
    protected $estruturaRepository;

    public function __construct(
        EstruturaRepository $estruturaRepository,
        HcmServices $hcmServices
    ) {
        $this->estruturaRepository = $estruturaRepository;
        $this->hcmServices = $hcmServices;
    }

    public function getEstruturasGerenciais(
        int $nrOrg,
        string $cdOperador
    ) : array {

        $hcmServicesRoute = 'getEstruturasGerenciais';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'CDOPERADOR'      => $cdOperador
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $estruturas = $response['dataset'][$hcmServicesRoute];

        return $estruturas;
    }

    public function getNrEstruturasGerenciais(
        int $nrOrg,
        string $cdOperador
    ) : array {

        $hcmServicesRoute = 'getNrEstruturasGerenciais';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'CDOPERADOR'      => $cdOperador
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $estruturas = $response['dataset'][$hcmServicesRoute];

        return $estruturas;
    }

    public function getEstruturasInferiores(
        int $nrOrg,
        int $nrEstrutura
    ) {
        $hcmServicesRoute = 'getEstruturasInferiores';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM'      => $nrEstrutura
            ]
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $estruturas = $response['dataset'][$hcmServicesRoute];

        return $estruturas;
    }

    public function getEstrutura(
        int     $nrOrg,
        $nmTipoEstrutura = null
    ) {
        $hcmServicesRoute = 'getEstrutura';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NMTIPOESTRUTURA' => $nmTipoEstrutura,
            ],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $result = $response['dataset'][$hcmServicesRoute];

        return $result;
    }

    public function getAniversariantesEstrutura(
        int $nrOrg,
        int $nrEstrutura
    ) {
        $hcmServicesRoute = 'getAniversariantesEstrutura';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM' => $nrEstrutura,
            ],
        ];

        $response = $this->hcmServices->send($hcmServicesRoute, $params, $nrOrg);
        $result = $response['dataset'][$hcmServicesRoute];

        return $result;
    }
}
